EXPORTS
	?ContentEnabled@CNsmlContentData@@QAEHXZ @ 1 NONAME ; int CNsmlContentData::ContentEnabled(void)
	?ExternalizeToCenrepL@CNsmlProfileUtil@@QAEXXZ @ 2 NONAME ; void CNsmlProfileUtil::ExternalizeToCenrepL(void)
	?ImplementationId@CNsmlContentData@@QAEHXZ @ 3 NONAME ; int CNsmlContentData::ImplementationId(void)
	?InternalizeFromCenrepL@CNsmlProfileUtil@@QAEXXZ @ 4 NONAME ; void CNsmlProfileUtil::InternalizeFromCenrepL(void)
	?InternalizeFromSettingsDBL@CNsmlProfileUtil@@QAEXH@Z @ 5 NONAME ; void CNsmlProfileUtil::InternalizeFromSettingsDBL(int)
	?IsSame@CNsmlProfileUtil@@QAEHAAV1@@Z @ 6 NONAME ; int CNsmlProfileUtil::IsSame(class CNsmlProfileUtil &)
	?NewL@CNsmlContentData@@SAPAV1@XZ @ 7 NONAME ; class CNsmlContentData * CNsmlContentData::NewL(void)
	?NewL@CNsmlProfileUtil@@SAPAV1@XZ @ 8 NONAME ; class CNsmlProfileUtil * CNsmlProfileUtil::NewL(void)
	?NewLC@CNsmlContentData@@SAPAV1@XZ @ 9 NONAME ; class CNsmlContentData * CNsmlContentData::NewLC(void)
	?NewLC@CNsmlProfileUtil@@SAPAV1@XZ @ 10 NONAME ; class CNsmlProfileUtil * CNsmlProfileUtil::NewLC(void)
	?ProfileId@CNsmlProfileUtil@@QAEHXZ @ 11 NONAME ; int CNsmlProfileUtil::ProfileId(void)
	?ServerDataSource@CNsmlContentData@@QAEPAVHBufC16@@XZ @ 12 NONAME ; class HBufC16 * CNsmlContentData::ServerDataSource(void)
	?SetContentEnabled@CNsmlContentData@@QAEXH@Z @ 13 NONAME ; void CNsmlContentData::SetContentEnabled(int)
	?SetImplementationId@CNsmlContentData@@QAEXH@Z @ 14 NONAME ; void CNsmlContentData::SetImplementationId(int)
	?SetServerDataSourceL@CNsmlContentData@@QAEXABVTDesC16@@@Z @ 15 NONAME ; void CNsmlContentData::SetServerDataSourceL(class TDesC16 const &)
	?AccessPointIdL@CNsmlProfileUtil@@QAEXAAH@Z @ 16 NONAME ; void CNsmlProfileUtil::AccessPointIdL(int &)
	?IsValidResumeL@CNsmlProfileUtil@@QAEXAAH@Z @ 17 NONAME ; void CNsmlProfileUtil::IsValidResumeL(int &)
	?WriteAccessPointIdL@CNsmlProfileUtil@@QAEXH@Z @ 18 NONAME ; void CNsmlProfileUtil::WriteAccessPointIdL(int)
	?WriteInterruptFlagL@CNsmlProfileUtil@@QAEXH@Z @ 19 NONAME ; void CNsmlProfileUtil::WriteInterruptFlagL(int)
	?ExternalizeTaskIdL@CNsmlProfileUtil@@QAEXV?$RArray@H@@@Z @ 20 NONAME ; void CNsmlProfileUtil::ExternalizeTaskIdL(class RArray<int>)
	?InternalizeTaskIdL@CNsmlProfileUtil@@QAEXAAV?$RArray@H@@@Z @ 21 NONAME ; void CNsmlProfileUtil::InternalizeTaskIdL(class RArray<int> &)

